@@ -19,6 +19,10 @@
 Module for some "global" constants
 """
 
+from picuplib.misc import gen_user_agent
+
+__version__ = '0.3.1'
+
 API_URL = 'https://picflash.org/tool.php'
 
 ALLOWED_RESIZE = ('80x80', '100x75', '100x100', '150x112', '468x60', '400x400',
@@ -26,3 +30,5 @@ ALLOWED_RESIZE = ('80x80', '100x75', '100x100', '150x112', '468x60', '400x400',
                   '1600x1200', 'og')
 
 ALLOWED_ROTATION = ('00', '90', '180', '270')
+
+USER_AGENT = gen_user_agent(__version__)
