@@ -22,11 +22,13 @@ This module handels the entire upload and some argument and response checking
 from __future__ import unicode_literals, print_function
 
 from requests import post
+from os.path import splitext, basename
+from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
+
 
 from picuplib.checks import (check_resize, check_rotation, check_noexif,
                              check_response, check_if_redirect)
-
-from picuplib.globals import API_URL
+from picuplib.globals import API_URL, USER_AGENT
 
 class Upload(object):
     """
@@ -135,14 +137,14 @@ class Upload(object):
 
 def punify_filename(filename):
     """
-    small hackisch workarounf for picflash unicode problems
+    small hackisch workaround for unicode problems with the picflash api
     """
-    path, extension = filename.rsplit('.', 1)
-    extension = '.' + extension
+    path, extension = splitext(filename)
     return path.encode('punycode').decode('utf8') + extension
 
 
-def upload(apikey, picture, resize='og', rotation='00', noexif=False):
+def upload(apikey, picture, resize='og', rotation='00', noexif=False,
+           callback=None):
     """
     prepares post for regular upload
 
@@ -161,9 +163,9 @@ def upload(apikey, picture, resize='og', rotation='00', noexif=False):
     post_data = compose_post(apikey, resize, rotation, noexif)
 
     with open(picture, 'rb') as file_obj:
-        post_data['Datei[]'] = (punify_filename(picture), file_obj)
+        post_data['Datei[]'] = (punify_filename(basename(picture)), file_obj)
 
-        return do_upload(post_data)
+        return do_upload(post_data, callback)
 
 def remote_upload(apikey, picture_url, resize='og',
                   rotation='00', noexif=False):
@@ -186,8 +188,6 @@ def remote_upload(apikey, picture_url, resize='og',
     if url:
         picture_url = resolve_redirect(url)
 
-    print(picture_url)
-
     post_data = compose_post(apikey, resize, rotation, noexif)
     post_data['url[]'] = ('', picture_url)
 
@@ -221,11 +221,18 @@ def compose_post(apikey, resize, rotation, noexif):
 
     return post_data
 
-def do_upload(post_data):
+def do_upload(post_data, callback=None):
     """
-    does the actual upload
+    does the actual upload also sets and generates the user agent string
     """
-    response = post(API_URL, files=post_data)
+
+    encoder = MultipartEncoder(post_data)
+    monitor = MultipartEncoderMonitor(encoder, callback)
+
+
+
+    headers = {'User-Agent': USER_AGENT, 'Content-Type': monitor.content_type}
+    response = post(API_URL, data=monitor, headers=headers)
     check_response(response)
 
     return response.json()[0]
